@@ -1,14 +1,3 @@
-/*
-    Qalculate    
-
-    Copyright (C) 2003  Niklas Knutsson (nq@altern.org)
-
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-*/
-
 #ifndef SUPPORT_H
 #define SUPPORT_H
 
@@ -22,7 +11,9 @@
 #ifdef ENABLE_NLS
 #  include <libintl.h>
 #  undef _
-#  define _(String) dgettext (PACKAGE, String)
+#  define _(String) dgettext (GETTEXT_PACKAGE, String)
+#  undef _n
+#  define _n(String, String_plural, n) dngettext (GETTEXT_PACKAGE, String, String_plural, n)
 #  ifdef gettext_noop
 #    define N_(String) gettext_noop (String)
 #  else
@@ -35,6 +26,7 @@
 #  define dcgettext(Domain,Message,Type) (Message)
 #  define bindtextdomain(Domain,Directory) (Domain)
 #  define _(String) (String)
+#  define _n(String, String_plural, n) (String)
 #  define N_(String) (String)
 #endif
 
